@@ -7,6 +7,7 @@ from rest_framework.views import APIView
 
 from ..services.thread_other_list_service import ThreadOtherListServices
 from ..utils.custom_response import util_response
+from ..utils.model_handle import parse_data, request_params_wrapper
 
 t = ThreadOtherListServices()
 
@@ -16,8 +17,9 @@ class CategoryListAPIView(APIView):
     get:类别列表
     """
 
-    def get(self, request, *args, **kwargs):
-        data, error_text = t.thread_category()
+    @request_params_wrapper
+    def get(self, request=None, request_params=None, *args, **kwargs):
+        data, error_text = t.thread_category(request_params)
         return util_response(data=data)
 
 
@@ -27,8 +29,12 @@ class ClassifyListAPIView(APIView):
     """
 
     def get(self, request, *args, **kwargs):
-        category_value = request.query_params.get('category_value', None)
-        data, error_text = t.thread_classify(category_value=category_value)
+        request_params = parse_data(request)
+        print(request_params)
+        category_value = request_params.get('category_value', None)
+        category_id = request_params.get('category_id', None)
+        classify_value = request_params.get('classify_value', None)
+        data, error_text = t.thread_classify(category_value=category_value, category_id=category_id, classify_value=classify_value)
         return util_response(data=data)
 
 
@@ -58,7 +64,7 @@ class TagListAPIView(APIView):
     """
 
     def get(self, request):
-        params = request.query_params.copy()
+        params = parse_data(request)
         data, error_text = t.thread_tag(params)
         return util_response(data=data)
 
@@ -67,8 +73,8 @@ class ThreadExtendFieldList(APIView):
     """扩展字段列表"""
 
     def get(self, request):
-        classify_id = request.GET.get("classify_id", None)
-        data, err = t.thread_extend_field_list(classify_id)
+        params = parse_data(request)
+        data, err = t.thread_extend_field_list(params)
         if err:
             return util_response(err=54555, msg=err)
         return util_response(data=data)
