@@ -21,13 +21,12 @@ class ThreadItemService:
     @staticmethod
     def add(params):
         # 扩展字段与主表字段拆分
-        # 开启事务，防止脏数据
         filter_filed_list = [  # 主表过滤字段
             "category_id", 'classify_id', 'show_id', 'user_id', 'auth_id', 'title', 'content', 'summary', 'ip',
             'has_enroll', 'has_fee',
             'has_comment', 'cover', "video", "photos", 'files', "price", "author", "create_time", "logs", "more"
         ]
-        # 主编篇插入
+        # 主表插入
         main_form_data = format_params_handle(
             params.copy(), filter_filed_list=filter_filed_list,
             alias_dict={'category_id': 'category_id_id', 'classify_id': 'classify_id_id'}
@@ -36,10 +35,9 @@ class ThreadItemService:
             instance = Thread.objects.create(**main_form_data)
         except Exception as e:
             return None, f'''{str(e)} in "{str(e.__traceback__.tb_frame.f_globals["__file__"])}" : Line {str(e.__traceback__.tb_lineno)}'''
-        # 扩展表插入
+        # 扩展表插入或更新
         except_main_form_data = format_params_handle(params.copy(), remove_filed_list=filter_filed_list)
-        ThreadExtendService.create_or_update(except_main_form_data, instance.id,
-                                             main_form_data.get("category_id_id", None))
+        ThreadExtendService.create_or_update(except_main_form_data, instance.id, main_form_data.get("category_id_id", None))
         return {"id": instance.id}, None
 
     @staticmethod
@@ -62,7 +60,8 @@ class ThreadItemService:
     @staticmethod
     def edit(form_data, pk):
         form_data.setdefault("id", pk)
-        filter_filed_list = [  # 主表过滤字段
+        # 主表过滤字段
+        filter_filed_list = [
             "category_id", 'classify_id', 'show_id', 'user_id', 'auth_id', 'title', 'content', 'summary', 'ip', 'has_enroll', 'has_fee',
             'has_comment', 'cover', "video", "photos", 'files', "price", "author", "create_time", "logs", "more"
         ]
@@ -71,14 +70,14 @@ class ThreadItemService:
         if not main_res:
             return None, "数据不存在，无法进行修改"
         try:
+            # 主表修改
             main_form_data = format_params_handle(form_data.copy(), filter_filed_list=filter_filed_list)
             main_res.update(**main_form_data)
+            # 扩展字段修改
+            except_main_form_data = format_params_handle(form_data.copy(), remove_filed_list=filter_filed_list)  # 排除主表之外的字段，理论上就是扩展字段，接下来仅仅需要转换一下扩展字段
+            return ThreadExtendService.create_or_update(except_main_form_data, pk, main_form_data.get("category_id", None))
         except Exception as e:
-            return None, "信息主表写入异常：" + str(e)
-        # 扩展字段修改
-        # 排除主表之外的字段，理论上就是扩展字段，接下来仅仅需要转换一下扩展字段
-        except_main_form_data = format_params_handle(form_data.copy(), remove_filed_list=filter_filed_list)
-        return ThreadExtendService.create_or_update(except_main_form_data, pk, main_form_data.get("category_id", None))
+            return None, "信息主表写入异常：" + str(e) + "  line:" + str(e.__traceback__.tb_lineno)
 
     @staticmethod
     def delete(id):
