@@ -19,6 +19,7 @@ from ..models import ThreadShow
 from ..models import ThreadTag
 from ..serializers import ThreadAuthListSerializer
 from ..serializers import ThreadTagSerializer
+from ..utils.model_handle import format_params_handle
 
 log = logging.getLogger()
 
@@ -28,17 +29,34 @@ class ThreadOtherListServices:
         pass
 
     @staticmethod
-    def thread_category():
+    def thread_category(params):
         """
         类别。类似于版块大类的概念，用于圈定信息内容所属的主要类别
         """
-        thread_category_obj = ThreadCategory.objects.all()
+        category_set = ThreadCategory.objects
+        params = format_params_handle(
+            param_dict=params,
+            filter_filed_list=["id", "platform_code", "category_value", "name", "need_auth", "description", "sort", "parent_id", ],
+            alias_dict={"name": "name__contains"}
+        )
+        if params:
+            category_set = category_set.filter(**params)
+        thread_category_obj = category_set.annotate(category_value=F('value')).values(
+            "id",
+            "platform_code",
+            "category_value",
+            "name",
+            "need_auth",
+            "description",
+            "sort",
+            "parent_id",
+        )
         if not thread_category_obj:
             return [], None
-        return thread_category_obj.to_json(), None
+        return list(thread_category_obj), None
 
     @staticmethod
-    def thread_classify(category_value=None, category_id=None, ):
+    def thread_classify(category_value=None, category_id=None, classify_value=None, classify_description=None):
         """
         分类。具体的分类，可以是按行业、兴趣、学科的分类，是主类别下的子分类。
         """
@@ -47,6 +65,10 @@ class ThreadOtherListServices:
             classify_set = classify_set.filter(category_id=category_id)
         if category_value:
             classify_set = classify_set.filter(category_id__value=category_value)
+        if classify_value:
+            classify_set = classify_set.filter(value=classify_value)
+        if classify_description:
+            classify_set = classify_set.filter(description=classify_description)
         classify_set = classify_set.annotate(category_value=F('category_id__value'))
         classify_set = classify_set.annotate(show_value=F('show_id__value'))
         return list(classify_set.values()), None
@@ -91,12 +113,14 @@ class ThreadOtherListServices:
         return data, None
 
     @staticmethod
-    def thread_extend_field_list(classify_id=None):
+    def thread_extend_field_list(params):
         """获取所有的扩展字段列表"""
-        obj_list = ThreadExtendField.objects.annotate(field_label=F("value")).values("field", 'field_label', 'category_id', 'type', 'unit', 'config')
-        if not classify_id is None:
-            if type(classify_id) is list or type(classify_id) is tuple:
-                obj_list = obj_list.filter(classify_id__in=classify_id)
-            else:
-                obj_list = obj_list.filter(classify_id=classify_id)
+        params = format_params_handle(
+            param_dict=params,
+            filter_filed_list=["category_value", "category_id", "id"],
+            alias_dict={"category_value": "category__value"}
+        )
+        extend_field_obj = ThreadExtendField.objects.annotate(field_label=F("value")).annotate(category_value=F("category__value")).annotate(category_description=F("category__description"))
+        extend_field_obj = extend_field_obj.filter(**params)
+        obj_list = extend_field_obj.values('category_value', 'category_description', 'category_id', "field", 'field_label', 'type', 'unit', 'config')
         return list(obj_list), None
