@@ -8,9 +8,13 @@
 """
 
 # ===========  工具方法 start =============
+from urllib.parse import parse_qs
 
 from django.core import serializers
+from django.core.handlers.wsgi import WSGIRequest
 from django.core.paginator import Paginator
+from rest_framework.request import Request
+import xmltodict
 
 from .custom_response import *
 
@@ -40,11 +44,11 @@ def format_params_handle(param_dict, filter_filed_list=None, remove_filed_list=N
 
     # 类型判断 过滤字段
     if filter_filed_list and isinstance(filter_filed_list, list):
-        param_dict = {k: v for k, v in param_dict.copy().items() if k in filter_filed_list}
+        param_dict = {k: v for k, v in param_dict.copy().items() if k in filter_filed_list and v}
 
     # 类型判断， 剔除字段
     if remove_filed_list and isinstance(remove_filed_list, list):
-        param_dict = {k: v for k, v in param_dict.copy().items() if not k in remove_filed_list}
+        param_dict = {k: v for k, v in param_dict.copy().items() if not k in remove_filed_list and v}
 
     # 类型判断 字段转换
     if alias_dict and isinstance(alias_dict, dict):
@@ -54,20 +58,89 @@ def format_params_handle(param_dict, filter_filed_list=None, remove_filed_list=N
 
 
 # 请求参数解析
-def parse_data(request, **kwargs):
+def parse_data(request):
     # 解析请求参数 兼容 APIView与View的情况，View 没有request.data
     content_type = request.META.get('CONTENT_TYPE', "").split(";")[0]
-    method = request.method
-    if method == "GET":
-        data = request.query_params
-    elif method == "POST":
+    if content_type == "application/json":
+        return json.loads(request.body)
+    elif content_type == "multipart/form-data":
+        data = request.POST
+    elif content_type == "application/xml":
+        try:
+            data = xmltodict.parse(request.body)
+            return data.get("body") or data.get("data", {})
+        except Exception as e:
+            data = {}
+    elif content_type == "application/x-www-form-urlencoded":
+        data = parse_qs(request.body.decode())
+        if data:
+            data = {k: v[0] for k, v in data.items()}
+        else:
+            data = {}
+    elif content_type == "text/plain":
+        try:
+            body = request.body.decode("utf-8")
+            data = json.loads(body)
+        except Exception:
+            data = request.GET
+
+    else:
+        data = getattr(request, 'data', {})
+    return {k: v for k, v in data.items()}
+
+
+# 请求参数解析
+def request_params_wrapper(func):
+    # 解析请求参数 兼容 APIView与View的情况，View 没有request.data
+    def wrapper(instance, arg_request=None, *args, request=None, **kwargs):
+        """
+        @param instance 实例是一个APIView的实例
+        @param args 其它可变参数元组
+        @param kwargs 其它可变关键字参数字典
+        """
+        if isinstance(instance, WSGIRequest) or isinstance(instance, Request):
+            request = instance
+        if isinstance(arg_request, WSGIRequest) or isinstance(arg_request, Request):
+            request = arg_request
+        if request is None:
+            return func(instance * args, request=request, request_params={}, **kwargs, )
+        # 参数解析
+        content_type = request.META.get('CONTENT_TYPE', "").split(";")[0]
+        method = request.method
+        # print("content_type:", content_type, "method:", method)
         if content_type == "application/json":
             data = json.loads(request.body)
-        else:
+        elif content_type == "multipart/form-data":
             data = request.POST
-    else:
-        data = request.data
-    return format_params_handle({k: v for k, v in data.items()}, **kwargs)
+        elif content_type == "application/xml":
+            try:
+                data = xmltodict.parse(request.body)
+                data = data.get("body") or data.get("data", {})
+            except Exception as e:
+                data = {}
+        elif content_type == "application/x-www-form-urlencoded":
+            data = parse_qs(request.body.decode())
+            if data:
+                data = {k: v[0] for k, v in data.items()}
+            else:
+                data = {}
+        elif content_type == "text/plain":
+            try:
+                body = request.body.decode("utf-8")
+                data = json.loads(body)
+            except Exception:
+                data = request.GET
+                if not data:
+                    data = request.POST
+                if not data:
+                    data = {}
+        else:
+            data = getattr(request, 'data', {})
+        # 闭包抛出
+        response = func(instance, *args, request=request, request_params={k: v for k, v in data.items()}, **kwargs, )
+        return response
+
+    return wrapper
 
 
 # 模型解析
