@@ -32,13 +32,13 @@ class ThreadAddValidator(Validate):
     #     validators=[is_set_category_id]
     # )
     #
-    # classify_id = forms.IntegerField(
-    #     required=True,
-    #     error_messages={
-    #         "required": "classify_id 必填",
-    #     },
-    #     validators=[is_set_classify_id]
-    # )
+    classify_id = forms.IntegerField(
+        required=True,
+        error_messages={
+            "required": "classify_id 必填",
+        },
+        validators=[is_set_classify_id]
+    )
 
     title = forms.CharField(
         required=True,
